=======
History
=======

0.1.2 (2018-09-18)
------------------

* Implemented new merging method `merge_labels_small2closest`.

0.1.1 (2018-09-18)
------------------

* Minor performance improvements in segmentation function.
* Resolved bugfix due to not importing functions through relative paths.
* Corrected erronous repository link on pypi.

0.1.0 (2018-09-07)
------------------

* First release on PyPI.
